# Django Online Docs

It works! When you see this page you have successfully installed
``django-online-docs``. In order to test the JavaScript part, just click at the
Docs link and see if a jQuery modal with this exact documentation pops up.

Below you will find some sample texts for testing your documentation
stylesheet.

## Subheading 2

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec a diam lectus. Sed sit amet ipsum mauris. Maecenas congue ligula ac quam viverra nec consectetur ante hendrerit. Donec et mollis dolor.

### Subheading 3

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec a diam lectus. Sed sit amet ipsum mauris. Maecenas congue ligula ac quam viverra nec consectetur ante hendrerit. Donec et mollis dolor.

#### Subheading 4

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec a diam lectus. Sed sit amet ipsum mauris. Maecenas congue ligula ac quam viverra nec consectetur ante hendrerit. Donec et mollis dolor.

##### Subheading 5

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec a diam lectus. Sed sit amet ipsum mauris. Maecenas congue ligula ac quam viverra nec consectetur ante hendrerit. Donec et mollis dolor.

__An unordered list__:

* Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec a diam lectus. Sed sit amet ipsum mauris. Maecenas congue ligula ac quam viverra nec consectetur ante hendrerit. Donec et mollis dolor.
* Lorem ipsum dolor sit amet,
* consectetur adipiscing elit.


__An ordered list__:

1. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Donec a diam lectus. Sed sit amet ipsum mauris. Maecenas congue ligula ac quam viverra nec consectetur ante hendrerit. Donec et mollis dolor.
2. Lorem ipsum dolor sit amet,
3. consectetur adipiscing elit.

__A link__ [foobar](www.google.com) between some text.

__A block of code__:

    $ cd /some/very/long/path/name/to/demonstrate/a/very/long/line/of/code/so/that/you/need/to/scroll/
    $ sudo rm -rf /

A `piece of code` between some text.

Can we have __strong__ text?

Can we have _italic_ text?
